@@ -168,6 +168,13 @@ sub setup {
 	print $F "Dir \"$chroot_dir\";\n";
     }
 
+# The cross build profile indicates that we cannot run host architecture binaries.
+# In that case, forbid installing host architecture binaries.
+    if (grep { $_ eq 'cross' } (split /\s+/, $self->get_conf('BUILD_PROFILES'))) {
+	my $host_arch = $self->get_conf('HOST_ARCH');
+	print $F qq(APT::BarbarianArchitectures {"$host_arch"};\n);
+    }
+
     close $F;
 
     if (!$session->rename($tmpaptconf, $aptconf)) {
@@ -809,7 +816,7 @@ sub dump_build_environment {
 
     my $arch = $self->get('Arch');
     my ($sysname, $nodename, $release, $version, $machine) = POSIX::uname();
-    $self->log_subsection("Build environment");
+    $self->log_subsection_t("Build environment", time);
     $self->log("Kernel: $sysname $release $version $arch ($machine)\n");
 
     $self->log("Toolchain package versions:");
@@ -857,9 +864,15 @@ sub run_apt {
     push @apt_command, '--allow-unauthenticated' if
 	($self->get_conf('APT_ALLOW_UNAUTHENTICATED'));
     if ( $self->get('Host Arch') ne $self->get('Build Arch') ) {
-	# drop m-a:foreign and essential:yes packages that are not arch:all
-	# and not arch:native
-	push @apt_command, '--solver', 'sbuild-cross-resolver';
+        my $session = $self->get('Session');
+        if (!$session->test_regular_file('/usr/lib/apt/solvers/apt')) {
+            $self->log_info("Not using sbuild-cross-resolver because apt-utils"
+                  . " is not installed inside the chroot\n");
+        } else {
+            # drop m-a:foreign and essential:yes packages that are not arch:all
+            # and not arch:native
+            push @apt_command, '--solver', 'sbuild-cross-resolver';
+        }
     }
     push @apt_command, "$mode", $action, @packages;
     my $pipe =
@@ -1232,10 +1245,16 @@ EOF
 
     # Now build the package:
     # NO_PKG_MANGLE=1 disables https://launchpad.net/pkgbinarymangler (only used on Ubuntu)
-    $session->run_command(
-	{ COMMAND => ['env', 'NO_PKG_MANGLE=1', 'dpkg-deb', '--build', $dummy_pkg_dir, $dummy_deb],
-	  USER => $self->get_conf('BUILD_USER'),
-	  PRIORITY => 0});
+    $session->run_command({
+            COMMAND => [
+                'env',      'NO_PKG_MANGLE=1',
+                'dpkg-deb', '--root-owner-group',
+                '--build',  $dummy_pkg_dir,
+                $dummy_deb
+            ],
+            USER     => $self->get_conf('BUILD_USER'),
+            PRIORITY => 0
+        });
     if ($?) {
 	$self->log("Dummy package creation failed\n");
 	return 0;
